@@ -323,11 +323,12 @@ class BaseTask(Persistent, Location):
                     subject = "[SCHEDULER ERROR] " + self.title
                 else:
                     subject = "[scheduler] " + self.title
-                message = TextMessage(subject=subject,
-                                      fromaddr=self.report_source,
-                                      toaddr=(self.report_target,),
-                                      text=report.getvalue())
-                mailer.send(self.report_source, (self.report_target,), message.as_string())
+                for target in self.report_target.split(';'):
+                    message = TextMessage(subject=subject,
+                                          fromaddr=self.report_source,
+                                          toaddr=(target,),
+                                          text=report.getvalue())
+                    mailer.send(self.report_source, (target,), message.as_string())
 
 
 #
